@@ -3,6 +3,7 @@ from collections import defaultdict
 from collections import deque
 from typing import Any as AnyType
 from typing import Callable
+from typing import ClassVar
 from typing import DefaultDict
 from typing import Deque
 from typing import Dict
@@ -13,16 +14,19 @@ from typing import Union
 
 from . import exceptions
 from .process_dispatcher import ProcessDispatcher
+from .process_recorder import ProcessRecorder
 from .types import COMMAND
 from .types import OPTIONAL_TEXT_OR_ITERABLE
 from .utils import Any
 from .utils import Command
+from .utils import Program
 
 
 class FakeProcess:
     """Main class responsible for process operations"""
 
-    any: Type[Any] = Any
+    any: ClassVar[Type[Any]] = Any
+    program: ClassVar[Type[Program]] = Program
 
     def __init__(self) -> None:
         self.definitions: DefaultDict[Command, Deque[Union[Dict, bool]]] = defaultdict(
@@ -46,7 +50,7 @@ class FakeProcess:
         signal_callback: Optional[Callable] = None,
         occurrences: int = 1,
         stdin_callable: Optional[Callable] = None,
-    ) -> None:
+    ) -> ProcessRecorder:
         """
         Main method for registering the subprocess instances.
 
@@ -68,6 +72,8 @@ class FakeProcess:
             )
         if not isinstance(command, Command):
             command = Command(command)
+
+        recorder = ProcessRecorder()
         self.definitions[command].extend(
             [
                 {
@@ -80,11 +86,14 @@ class FakeProcess:
                     "callback_kwargs": callback_kwargs,
                     "signal_callback": signal_callback,
                     "stdin_callable": stdin_callable,
+                    "recorder": recorder,
                 }
             ]
             * occurrences
         )
 
+        return recorder
+
     register_subprocess = register
 
     def pass_command(
